#[repr(i8)]pub enum LogLevelFilter {
Trace = 16,
Debug = 32,
Info = 48,
Warn = 64,
Error = 80,
Fatal = 96,
None = 127,
}Expand description
Log levels used with log related filtering. Filtering uses a heuristic based on a threshold of minimum severity level - with any log equal to or greater than the threshold being included in the printable logs.
Variants